/*Import CSV from Care Compare*/
proc import datafile='file location/Healthcare_Associated_Infections-Hospital_April_2024.csv' out=data1
        dbms=csv replace; 
        getnames=yes;
        datarow=2; 
        Run; 


/*Convert SIR to a numeric value and create a numeric value for provider ID*/
Data data1; 
    set data1; 
    SIR=.; 
    SIR=score; 
    CMS_ID='          ';
    CMS_ID=Facility_ID;
    If Facility_ID ne ''; /*Remove missing facility IDs*/
Run;
proc print data=data1 (obs=10); Run;
/*Convert SIR to a numeric value and create a numeric value for provider ID*/


Data CLABSI_expected; 
    set data1; 
    CLABSI_expected=.; 
    CLABSI_expected=score; 
    where MEASURE_ID='HAI_1_ELIGCASES';
    Keep Facility_ID Facility_Name CLABSI_expected;
Run;

Data CAUTI_expected; 
    set data1; 
    CAUTI_expected=.; 
    CAUTI_expected=score; 
    where MEASURE_ID='HAI_2_ELIGCASES';
    Keep Facility_ID Facility_Name CAUTI_expected;
Run;

Data SSI_COLON_expected; 
    set data1; 
    SSI_COLON_expected=.; 
    SSI_COLON_expected=score; 
    where MEASURE_ID='HAI_3_ELIGCASES';
    Keep Facility_ID Facility_Name SSI_COLON_expected;
Run;

Data SSI_HYST_expected; 
    set data1; 
    SSI_HYST_expected=.; 
    SSI_HYST_expected=score; 
    where MEASURE_ID='HAI_4_ELIGCASES';
    Keep Facility_ID Facility_Name SSI_HYST_expected;
Run;

Data MRSA_expected; 
    set data1; 
    MRSA_expected=.; 
    MRSA_expected=score; 
    where MEASURE_ID='HAI_5_ELIGCASES';
    Keep Facility_ID Facility_Name MRSA_expected;
Run;

Data CDIFF_expected;
    set data1; 
    CDIFF_expected=.; 
    CDIFF_expected=score; 
    where MEASURE_ID='HAI_6_ELIGCASES';
    Keep Facility_ID Facility_Name CDIFF_expected;
Run;

/*Merge all hospital expected HAIs into single dataset*/

proc sort data=CLABSI_expected; by FACILITY_ID; RUN;
proc sort data=CAUTI_expected; by FACILITY_ID; RUN;
proc sort data=SSI_COLON_expected; by FACILITY_ID; RUN;
proc sort data=SSI_HYST_expected; by FACILITY_ID; RUN;
proc sort data=MRSA_expected; by FACILITY_ID; RUN;
proc sort data=CDIFF_expected; by FACILITY_ID; RUN;

data merge_expected; 
    merge CLABSI_expected (In=a) 
          CAUTI_expected (In=b)  
          SSI_COLON_expected (In=c)   
          SSI_HYST_expected (In=d)   
          MRSA_expected (In=e)  
          CDIFF_expected (In=f) ; 
by facility_id; 

IF a & b & c & d & e & f; 
Run;
/*Merge all hospital expected HAIs into single dataset*/



/******Use macro to generate custom percentiles default=75********/
%macro calculate_percentile(measure_id, percentile, output_dataset);
    Proc rank data=data1 out=&output_dataset groups=100 descending;
        var SIR;
        ranks &measure_id._percentile;
        where MEASURE_ID="&measure_id.";
    Run;

    Proc sort data=&output_dataset;
        by descending &measure_id._percentile Score;
    Run;

    Data &output_dataset;
        set &output_dataset;
        by descending &measure_id._percentile Score;
        if last.&measure_id._percentile;
        where &measure_id._PERCENTILE=&percentile;
    Run;
%mend;

%calculate_percentile(HAI_1_SIR, 75, CLABSI);
%calculate_percentile(HAI_2_SIR, 75, CAUTI);
%calculate_percentile(HAI_3_SIR, 75, SSI_COLON);
%calculate_percentile(HAI_4_SIR, 75, SSI_HYST);
%calculate_percentile(HAI_5_SIR, 75, MRSA);
%calculate_percentile(HAI_6_SIR, 75, CDIFF);

Data percentiles;
    set CLABSI CAUTI SSI_COLON SSI_HYST MRSA CDIFF;
Run;

proc print data=percentiles (obs=10); 
Run;

Data percentiles2; 
    set percentiles;
    Keep SIR MEASURE_ID MEASURE_NAME HAI_1_SIR_percentile HAI_2_SIR_percentile HAI_3_SIR_percentile HAI_4_SIR_percentile HAI_5_SIR_percentile HAI_6_SIR_percentile; 
Run;


/*Create macro variables with value of SIR per HAI to be used in next data step*/
proc sql noprint;
 select SIR
 into: m_HAI_1_SIR
 from percentiles2
 where measure_id='HAI_1_SIR';
quit;

proc sql noprint;
 select SIR
 into: m_HAI_2_SIR
 from percentiles2
 where measure_id='HAI_2_SIR'; 
quit;

proc sql noprint;
 select SIR
 into: m_HAI_3_SIR
 from percentiles2
 where measure_id='HAI_3_SIR';
quit;

proc sql noprint;
 select SIR
 into: m_HAI_4_SIR
 from percentiles2
 where measure_id='HAI_4_SIR'; 
quit;

proc sql noprint;
 select SIR
 into: m_HAI_5_SIR
 from percentiles2
 where measure_id='HAI_5_SIR'; 
quit;

proc sql noprint;
 select SIR
 into: m_HAI_6_SIR
 from percentiles2
 where measure_id='HAI_6_SIR'; 
quit;


proc print data=percentiles2 (obs=10); 
Run;
/******Use macro to generate custom percentiles default=75********/


/*Calculate threshold count of each HAI using SIR benchmark percentile and the expected (eligible) risk*/
Data calculated; 
    set merge_expected;

    percentile75_SIR_CLABSI=&m_HAI_1_SIR; /*Obtain SIR value from percentile macro above*/
    CLABSI_threshold_count=.;
    CLABSI_threshold_count=FLOOR(percentile75_SIR_CLABSI*CLABSI_expected);
    
    percentile75_SIR_CAUTI=&m_HAI_2_SIR; /*Obtain SIR value from percentile macro below*/
    CAUTI_threshold_count=.;
    CAUTI_threshold_count=FLOOR(percentile75_SIR_CAUTI*CAUTI_expected);
    
    percentile75_SIR_SSI_COLON=&m_HAI_3_SIR; /*Obtain SIR value from percentile macro below*/
    SSI_Colon_threshold_count=.;
    SSI_Colon_threshold_count=FLOOR(percentile75_SIR_SSI_Colon*SSI_Colon_expected);
    
    percentile75_SIR_SSI_HYST=&m_HAI_4_SIR; /*Obtain SIR value from percentile macro below*/
    SSI_Hyst_threshold_count=.;
    SSI_Hyst_threshold_count=FLOOR(percentile75_SIR_SSI_Hyst*SSI_Hyst_expected);
    
    percentile75_SIR_MRSA=&m_HAI_5_SIR; /*Obtain SIR value from percentile macro below*/
    MRSA_threshold_count=.;
    MRSA_threshold_count=FLOOR(percentile75_SIR_MRSA*MRSA_expected);
    
    percentile75_SIR_CDIFF=&m_HAI_6_SIR; /*Obtain SIR value from percentile macro below*/
    CDIFF_threshold_count=.;
    CDIFF_threshold_count=FLOOR(percentile75_SIR_CDIFF*CDIFF_expected);
    
    where facility_id ne .; 
Run;

/*Calculate threshold count of each HAI using SIR benchmark percentile and the expected (eligible) risk*/


proc export
  data=calculated
  dbms=xlsx 
  outfile='file location/HAI_Threshold_File.xlsx' 
  replace;
run;

/*Analysis*/
Proc means data=calculated n nmiss mean std min p5 p25 p50 p75 p95 max;
    var CLABSI_threshold_count CAUTI_threshold_count SSI_Colon_threshold_count SSI_Hyst_threshold_count MRSA_threshold_count CDIFF_threshold_count;;
Run;

/*print SIR values to log*/
%put &=m_HAI_1_SIR;
%put &=m_HAI_2_SIR; 
%put &=m_HAI_3_SIR; 
%put &=m_HAI_4_SIR; 
%put &=m_HAI_5_SIR; 
%put &=m_HAI_6_SIR;

Data zeroes;
    set calculated;
    zero_clabsi=.;
    zero_cauti=.;
    zero_ssicolon=.;
    zero_ssihyst=.;
    zero_mrsa=.;
    zero_cdiff=.;
    If CLABSI_threshold_count=0 then zero_clabsi=1; if CLABSI_threshold_count>0 then zero_clabsi=0; 
    If CAUTI_threshold_count=0 then zero_cauti=1; if CAUTI_threshold_count>0 then zero_cauti=0; 
    If SSI_Colon_threshold_count=0 then zero_ssicolon=1; if SSI_Colon_threshold_count>0 then zero_ssicolon=0; 
    If SSI_Hyst_threshold_count=0 then zero_ssihyst=1; if SSI_Hyst_threshold_count>0 then zero_ssihyst=0; 
    If MRSA_threshold_count=0 then zero_mrsa=1; if MRSA_threshold_count>0 then zero_mrsa=0; 
    If CDIFF_threshold_count=0 then zero_cdiff=1; if CDIFF_threshold_count>0 then zero_cdiff=0; 
Run;


proc freq data=zeroes;
    tables zero_clabsi zero_cauti zero_ssicolon zero_ssihyst zero_mrsa zero_cdiff;
Run;




